TrustedDealerBuilder

Struct TrustedDealerBuilder 

pub struct TrustedDealerBuilder<E: Curve, L: SecurityLevel> { /* private fields */ }
Available on crate feature spof only.
Trusted dealer builder

Implementations

Source

impl<E: Curve, L: SecurityLevel> TrustedDealerBuilder<E, L>

pub fn new(n: u16) -> Self

Construct a trusted dealer builder

Takes amount of key shares n to be generated

pub fn set_threshold(self, t: Option<u16>) -> Self

Sets threshold value

If threshold is Some(_), resulting key shares will be generated using t-out-of-n VSS scheme. If it’s None, trusted dealer will generate additive key shares in n-out-ouf-n scheme.

Note that setting t=Some(n) is not the same as setting t=None. Both produce n-out-of-n key shares, but t=Some(n) mocks threshold key generation with threshold=n, t=None mock non-threshold key generation.

Default: None

pub fn set_shared_secret_key(self, sk: NonZero<SecretScalar<E>>) -> Self

Sets shared secret key to be generated

Resulting key shares will share specified secret key.

pub fn set_pregenerated_primes(self, primes: Vec<PregeneratedPrimes<L>>) -> Self

Sets pregenerated primes to use

primes should have exactly n pairs of primes.

pub fn enable_multiexp(self, v: bool) -> Self

Enables multiexp optimization

It takes additional time to precompute multiexp tables, and it makes the key shares larger, but it makes the signing and presignature generation protocols faster

pub fn hd_wallet(self, v: bool) -> Self

Available on crate feature hd-wallet only.

Specifies that the key being generated shall support HD derivation

pub fn generate_core_shares( self, rng: &mut (impl RngCore + CryptoRng), ) -> Result<Vec<IncompleteKeyShare<E>>, TrustedDealerError>

Generates IncompleteKeyShares

Returns error if provided inputs are invalid, or if internal error has occurred.

pub fn generate_shares( self, rng: &mut (impl RngCore + CryptoRng), ) -> Result<Vec<KeyShare<E, L>>, TrustedDealerError>

Generates KeyShares

Returns error if provided inputs are invalid, or if internal error has occurred.