pub struct TrustedDealerBuilder<E: Curve, L: SecurityLevel> { /* private fields */ }spof only.Expand description
Trusted dealer builder
Implementations
Sourceimpl<E: Curve, L: SecurityLevel> TrustedDealerBuilder<E, L>
impl<E: Curve, L: SecurityLevel> TrustedDealerBuilder<E, L>
Sourcepub fn new(n: u16) -> Self
pub fn new(n: u16) -> Self
Construct a trusted dealer builder
Takes amount of key shares n to be generated
Sourcepub fn set_threshold(self, t: Option<u16>) -> Self
pub fn set_threshold(self, t: Option<u16>) -> Self
Sets threshold value
If threshold is Some(_), resulting key shares will be generated
using t-out-of-n VSS scheme. If it’s None, trusted dealer will
generate additive key shares in n-out-ouf-n scheme.
Note that setting t=Some(n) is not the same as setting t=None.
Both produce n-out-of-n key shares, but t=Some(n) mocks threshold
key generation with threshold=n, t=None mock non-threshold key
generation.
Default: None
Sets shared secret key to be generated
Resulting key shares will share specified secret key.
Sourcepub fn set_pregenerated_primes(self, primes: Vec<PregeneratedPrimes<L>>) -> Self
pub fn set_pregenerated_primes(self, primes: Vec<PregeneratedPrimes<L>>) -> Self
Sets pregenerated primes to use
primes should have exactly n pairs of primes.
Sourcepub fn enable_multiexp(self, v: bool) -> Self
pub fn enable_multiexp(self, v: bool) -> Self
Enables multiexp optimization
It takes additional time to precompute multiexp tables, and it makes the key shares larger, but it makes the signing and presignature generation protocols faster
Sourcepub fn hd_wallet(self, v: bool) -> Self
Available on crate feature hd-wallet only.
pub fn hd_wallet(self, v: bool) -> Self
hd-wallet only.Specifies that the key being generated shall support HD derivation
Generates IncompleteKeyShares
Returns error if provided inputs are invalid, or if internal error has occurred.
Generates KeyShares
Returns error if provided inputs are invalid, or if internal error has occurred.